@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = 'v2.3.8';
+our $VERSION = 'v2.3';
 
 
 # Possible types of current directory:
@@ -37,13 +37,6 @@ __END__
 
 =encoding utf8
 
-=begin markdown
-
-[![Docker Automated Build](https://img.shields.io/docker/automated/powerman/narada.svg)](https://github.com/powerman/Narada)
-[![Docker Build Status](https://img.shields.io/docker/build/powerman/narada.svg)](https://hub.docker.com/r/powerman/narada/)
-
-=end markdown
-
 =head1 NAME
 
 Narada - framework for ease deploy and support microservice projects
@@ -51,10 +44,7 @@ Narada - framework for ease deploy and support microservice projects
 
 =head1 VERSION
 
-This document describes Narada version v2.3.8
-
-
-=head1 SYNOPSIS
+This document describes Narada version v2.3=head1 SYNOPSIS
 
     #--- Create new project
     ~ $ narada-new my_proj
@@ -1032,11 +1022,11 @@ Nick Levchenko E<lt>project129@yandex.ruE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2008- by Alex Efros E<lt>powerman@cpan.orgE<gt>.
+This software is Copyright (c) 2008-2015 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
 This is free software, licensed under:
 
   The MIT (X11) License
 
 
-=cut
+=cut
\ No newline at end of file
