@@ -4,9 +4,9 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = 'v2.3.8';
+our $VERSION = 'v2.3';
 
-use Export::Attrs;
+use Perl6::Export::Attrs;
 use Narada;
 use Path::Tiny 0.053;
 
@@ -75,10 +75,7 @@ Narada::Config - manage project configuration
 
 =head1 VERSION
 
-This document describes Narada::Config version v2.3.8
-
-
-=head1 SYNOPSIS
+This document describes Narada::Config version v2.3=head1 SYNOPSIS
 
     use Narada::Config;
 
@@ -102,34 +99,30 @@ to these files, this module provide easier way to do this.
 
 =head1 INTERFACE 
 
-=head2 get_config
+=over
 
-    $value = get_config( $name );
+=item B<get_config>( VARIABLE_NAME )
 
-$name must contain only [/A-Za-z0-9._-].
+VARIABLE_NAME must contain only [/A-Za-z0-9._-].
 It must not contain "./" or "../".
 
-Return: contents of file 'config/$name' as scalar.
+Return: contents of file 'config/VARIABLE_NAME' as scalar.
 
-=head2 get_config_line
-
-    $value = get_config_line( $name );
+=item B<get_config_line>( VARIABLE_NAME )
 
 Suitable for reading files which contain single string (with/without \n at end).
 
-$name must contain only [/A-Za-z0-9._-].
+VARIABLE_NAME must contain only [/A-Za-z0-9._-].
 It must not contain "./" or "../".
 
-Return: contents of file 'config/$name' as scalar without last \n
+Return: contents of file 'config/VARIABLE_NAME' as scalar without last \n
 (if any). Raise exception if file contain more than one line.
 
-=head2 get_db_config
-
-    $db_config = get_db_config();
+=item B<get_db_config>()
 
 Helper for reading database configuration from C<config/db/*>.
 
-Return: nothing if database not configured, or HASHREF with keys:
+Return: nothing if database not configured, or hashref with keys:
 
     {db}        contents of config/db/db
     {login}     contents of config/db/login
@@ -139,18 +132,18 @@ Return: nothing if database not configured, or HASHREF with keys:
     {dsn_nodb}  'dbi:mysql:;host=$host;port=$port'
     {dsn}       'dbi:mysql:;host=$host;port=$port;database=$db'
 
-=head2 set_config
+=item B<set_config>( VARIABLE_NAME, VARIABLE_VALUE )
 
-    set_config( $name, $value );
+See limitation for VARIABLE_VALUE above.
 
-See limitation for $name above.
-
-Atomically write $value (scalar) to file 'config/$name'.
-If 'config/$name' doesn't exist it will be created (including
+Atomically write VARIABLE_VALUE (scalar) to file 'config/VARIABLE_NAME'.
+If 'config/VARIABLE_NAME' doesn't exist it will be created (including
 parent directories if needed).
 
 Return: nothing.
 
+=back
+
 
 =head1 DIAGNOSTICS
 
@@ -221,7 +214,7 @@ Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2008- by Alex Efros E<lt>powerman@cpan.orgE<gt>.
+This software is Copyright (c) 2008-2015 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
 This is free software, licensed under:
 
