@@ -4,9 +4,9 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = 'v2.3.8';
+our $VERSION = 'v2.3';
 
-use Export::Attrs;
+use Perl6::Export::Attrs;
 use Narada;
 use Fcntl qw( :DEFAULT :flock F_SETFD FD_CLOEXEC );
 use Errno;
@@ -86,10 +86,7 @@ Narada::Lock - manage project locks
 
 =head1 VERSION
 
-This document describes Narada::Lock version v2.3.8
-
-
-=head1 SYNOPSIS
+This document describes Narada::Lock version v2.3=head1 SYNOPSIS
 
     use Narada::Lock qw( shared_lock unlock child_inherit_lock );
     use Narada::Lock qw( exclusive_lock unlock_new unlock );
@@ -152,9 +149,9 @@ exclusive lock again and continue these critical operations.
 
 =head1 INTERFACE 
 
-=head2 shared_lock
+=over
 
-    shared_lock( $timeout );
+=item B<shared_lock>( $timeout )
 
 Try to get shared lock which is required to modify any project data (files or
 database).
@@ -166,9 +163,7 @@ Use unlock() to free this lock.
 
 Return: true if able to get lock.
 
-=head2 exclusive_lock
-
-    exclusive_lock();
+=item B<exclusive_lock>()
 
 Try to get exclusive lock which is required to guarantee consistent project
 state (needed while backup/update/maintenance operations).
@@ -184,9 +179,7 @@ Use unlock_new() in combination with exit() or unlock() to free these locks.
 
 Return: nothing.
 
-=head2 unlock_new
-
-    unlock_new();
+=item B<unlock_new>()
 
 Free first lock set by exclusive_lock() (i.e. remove file C<.lock.new>).
 This allow other tasks to get shared_lock() after this process exit or
@@ -194,17 +187,13 @@ call unlock().
 
 Return: nothing.
 
-=head2 unlock
-
-    unlock();
+=item B<unlock>()
 
 Free lock set by shared_lock() (or second lock set by exclusive_lock()).
 
 Return: nothing.
 
-=head2 child_inherit_lock
-
-    child_inherit_lock( $is_inherit );
+=item B<child_inherit_lock>( $is_inherit )
 
 By default, child processes don't inherit our FD with lock.
 This is acceptable only if we don't run child in background or if
@@ -235,6 +224,8 @@ Examples:
 
 Return: nothing.
 
+=back
+
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
@@ -305,11 +296,11 @@ Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2008- by Alex Efros E<lt>powerman@cpan.orgE<gt>.
+This software is Copyright (c) 2008-2015 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
 This is free software, licensed under:
 
   The MIT (X11) License
 
 
-=cut
+=cut
\ No newline at end of file
